.. ascmhl documentation master file, created by
   sphinx-quickstart on Mon Aug  3 15:08:58 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ascmhl's documentation!
==================================

This documentation is for the ASC MHL command line tool ``ascmhl`` hosted on https://github.com/ascmitc/mhl.

The ASC MHL tool can

* create and extend ASC MHL history for given files and entire file hierarchies in a file system,
* output information about recorded history, and
* verify files and entire file hierarchies.

The "commands" section of this documentation is auto-generated from the Python source code, while the "ASC Media Hash List (ASC MHL)" section with detailled information is imported from the REAMDE.md of the ghithub repoistory at https://github.com/ascmitc/mhl.


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   README
   commands



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`


This documentation is created automatically from https://github.com/ascmitc/mhl.